@@ -17,6 +17,7 @@ import requests
 import urllib3
 
 import pynitrokey.nethsm
+from pynitrokey.helpers import prompt
 
 
 def make_enum_type(enum_cls):
@@ -79,7 +80,7 @@ def print_table(headers, data):
 )
 @click.pass_context
 def nethsm(ctx, host, version, username, password, verify_tls):
-    """Interact with NetHSM, see subcommands."""
+    """Interact with NetHSM devices, see subcommands."""
     ctx.ensure_object(dict)
 
     ctx.obj["NETHSM_HOST"] = host
@@ -104,13 +105,15 @@ def connect(ctx, require_auth=True):
         username = ctx.obj["NETHSM_USERNAME"]
         password = ctx.obj["NETHSM_PASSWORD"]
         if not username:
-            username = click.prompt(f"[auth] User name for NetHSM {host}")
+            username = prompt(f"[auth] User name for NetHSM {host}")
         if not password:
-            password = click.prompt(
+            password = prompt(
                 f"[auth] Password for user {username} on NetHSM {host}", hide_input=True
             )
 
-    with pynitrokey.nethsm.connect(host, version, username, password, verify_tls) as nethsm:
+    with pynitrokey.nethsm.connect(
+        host, version, username, password, verify_tls
+    ) as nethsm:
         import urllib3.exceptions
 
         try:
@@ -119,11 +122,15 @@ def connect(ctx, require_auth=True):
             raise click.ClickException(e)
         except urllib3.exceptions.MaxRetryError as e:
             if isinstance(e.reason, urllib3.exceptions.SSLError):
-                raise click.ClickException(f"Could not connect to the NetHSM: {e.reason}\nIf you use a self-signed certificate, please set the --no-verify-tls option.")
+                raise click.ClickException(
+                    f"Could not connect to the NetHSM: {e.reason}\nIf you use a self-signed certificate, please set the --no-verify-tls option."
+                )
             else:
                 raise e
         except requests.exceptions.SSLError as e:
-            raise click.ClickException(f"Could not connect to the NetHSM: {e}\nIf you use a self-signed certificate, please set the --no-verify-tls option.")
+            raise click.ClickException(
+                f"Could not connect to the NetHSM: {e}\nIf you use a self-signed certificate, please set the --no-verify-tls option."
+            )
 
 
 @nethsm.command()
@@ -133,7 +140,7 @@ def unlock(ctx, passphrase):
     """Bring a locked NetHSM into operational state."""
     with connect(ctx, require_auth=False) as nethsm:
         if not passphrase:
-            passphrase = click.prompt(
+            passphrase = prompt(
                 f"Unlock passphrase for NetHSM {nethsm.host}", hide_input=True
             )
         nethsm.unlock(passphrase)
@@ -438,8 +445,10 @@ def prompt_mechanisms(type):
         print(f"Automatically selecting the key mechanism {available_mechanisms[0]}")
         return available_mechanisms
 
-    print("Please enter at least one mechanism.  Enter an empty string to "
-          "finish the list of mechanisms.")
+    print(
+        "Please enter at least one mechanism.  Enter an empty string to "
+        "finish the list of mechanisms."
+    )
 
     mechanism_type = click.Choice(available_mechanisms, case_sensitive=False)
     mechanisms = []
@@ -450,7 +459,7 @@ def prompt_mechanisms(type):
         if mechanisms:
             prompt += " (or empty string to continue)"
             default = ""
-        mechanism = click.prompt(
+        mechanism = prompt(
             prompt,
             type=mechanism_type,
             default=default,
@@ -523,20 +532,22 @@ def add_key(ctx, type, mechanisms, prime_p, prime_q, public_exponent, data, key_
         if data:
             raise click.ClickException("-d/--data must not be set for RSA keys")
         if not prime_p:
-            prime_p = click.prompt("Prime p")
+            prime_p = prompt("Prime p")
         if not prime_q:
-            prime_q = click.prompt("Prime q")
+            prime_q = prompt("Prime q")
         if not public_exponent:
-            public_exponent = click.prompt("Public exponent")
+            public_exponent = prompt("Public exponent")
     else:
         if prime_p:
             raise click.ClickException("-p/--prime-p may only be set for RSA keys")
         if prime_q:
             raise click.ClickException("-q/--prime-q may only be set for RSA keys")
         if public_exponent:
-            raise click.ClickException("-e/--public-exponent may only be set for RSA keys")
+            raise click.ClickException(
+                "-e/--public-exponent may only be set for RSA keys"
+            )
         if not data:
-            data = click.prompt("Key data")
+            data = prompt("Key data")
 
     with connect(ctx) as nethsm:
         key_id = nethsm.add_key(
@@ -796,14 +807,14 @@ def get_api_or_key_id(api, key_id):
 
     if not api and not key_id:
         choice = click.Choice(["api", "key"], case_sensitive=False)
-        method = click.prompt(
+        method = prompt(
             "For stored key or for NetHSM HTTPS API?",
             type=choice,
         )
         if method == "api":
             api = True
         elif method == "key":
-            key_id = click.prompt("Key ID")
+            key_id = prompt("Key ID")
         else:
             raise ValueError("Unexpected method")
 
@@ -811,7 +822,9 @@ def get_api_or_key_id(api, key_id):
 
 
 @nethsm.command()
-@click.option("-a", "--api", is_flag=True, help="Set the certificate for the NetHSM HTTPS API")
+@click.option(
+    "-a", "--api", is_flag=True, help="Set the certificate for the NetHSM HTTPS API"
+)
 @click.option("-k", "--key-id", help="The ID of the key to set the certificate for")
 @click.option(
     "-m",
@@ -847,7 +860,9 @@ def set_certificate(ctx, api, key_id, mime_type, filename):
                         f"{filename}"
                     )
                 nethsm.set_key_certificate(key_id, f, mime_type)
-                print(f"Updated the certificate for key {key_id} on NetHSM {nethsm.host}")
+                print(
+                    f"Updated the certificate for key {key_id} on NetHSM {nethsm.host}"
+                )
             else:
                 if mime_type:
                     raise click.ClickException("--mime-type cannot be used with --api")
@@ -856,7 +871,9 @@ def set_certificate(ctx, api, key_id, mime_type, filename):
 
 
 @nethsm.command()
-@click.option("-a", "--api", is_flag=True, help="Get the certificate for the NetHSM HTTPS API")
+@click.option(
+    "-a", "--api", is_flag=True, help="Get the certificate for the NetHSM HTTPS API"
+)
 @click.option("-k", "--key-id", help="The ID of the key to get the certificate for")
 @click.pass_context
 def get_certificate(ctx, api, key_id):
@@ -897,18 +914,34 @@ def delete_certificate(ctx, key_id):
 
 
 @nethsm.command()
-@click.option("-a", "--api", is_flag=True, help="Generate a CSR for the NetHSM HTTPS API")
+@click.option(
+    "-a", "--api", is_flag=True, help="Generate a CSR for the NetHSM HTTPS API"
+)
 @click.option("-k", "--key-id", help="The ID of the key to generate the CSR for")
 @click.option("--country", default="", prompt=True, help="The country name")
-@click.option("--state-or-province", default="", prompt=True, help="The state or province name")
+@click.option(
+    "--state-or-province", default="", prompt=True, help="The state or province name"
+)
 @click.option("--locality", default="", prompt=True, help="The locality name")
 @click.option("--organization", default="", prompt=True, help="The organization name")
-@click.option("--organizational-unit", default="", prompt=True, help="The organization unit name")
+@click.option(
+    "--organizational-unit", default="", prompt=True, help="The organization unit name"
+)
 @click.option("--common-name", default="", prompt=True, help="The common name")
 @click.option("--email-address", default="", prompt=True, help="The email address")
 @click.pass_context
-def csr(ctx, api, key_id, country, state_or_province, locality, organization, organizational_unit,
-        common_name, email_address):
+def csr(
+    ctx,
+    api,
+    key_id,
+    country,
+    state_or_province,
+    locality,
+    organization,
+    organizational_unit,
+    common_name,
+    email_address,
+):
     """Generate a certificate signing request.
 
     If the --api option is set, the CSR is generated for the NetHSM, for
@@ -970,7 +1003,7 @@ def backup(ctx, filename):
         raise click.ClickException(f"Backup file {filename} already exists")
     with connect(ctx) as nethsm:
         data = nethsm.backup()
-        with open(filename, 'xb') as f:
+        with open(filename, "xb") as f:
             f.write(data)
             print(f"Backup for {nethsm.host} written to {filename}")
 
